from allauth.socialaccount import app_settings
from allauth.socialaccount.adapter import get_adapter
from allauth.socialaccount.providers.oauth2.views import (
    OAuth2Adapter,
    OAuth2CallbackView,
    OAuth2LoginView,
)


class SuapOAuth2Adapter(OAuth2Adapter):
    provider_id = "suap"
    settings = app_settings.PROVIDERS.get(provider_id, {})

    if "SUAP_URL" in settings:
        web_url = settings.get("SUAP_URL").rstrip("/")
        api_url = f"{web_url}/api"
    else:
        web_url = "https://suap.ifrn.edu.br"
        api_url = "https://suap.ifrn.edu.br/api"

    access_token_url = f"{web_url}/o/token/"
    authorize_url = f"{web_url}/o/authorize/"
    profile_url = f"{api_url}/rh/eu/"

    def complete_login(self, request, app, token, **kwargs):
        headers = {"Authorization": "Bearer {}".format(token.token)}
        resp = (
            get_adapter().get_requests_session().get(self.profile_url, headers=headers)
        )
        resp.raise_for_status()
        extra_data = resp.json()
        return self.get_provider().sociallogin_from_response(request, extra_data)


oauth2_login = OAuth2LoginView.adapter_view(SuapOAuth2Adapter)
oauth2_callback = OAuth2CallbackView.adapter_view(SuapOAuth2Adapter)



from allauth.socialaccount.providers.base import ProviderAccount
from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
from .views import SuapOAuth2Adapter


class SuapAccount(ProviderAccount):
    def get_avatar_url(self):
        return self.account.extra_data.get("foto")


class SuapOAuth2Provider(OAuth2Provider):
    id = "suap"
    name = "SUAP"
    account_class = SuapAccount
    oauth2_adapter_class = SuapOAuth2Adapter

    def get_default_scope(self):
        scope = ["identificacao", "email"]
        return scope

    def extract_uid(self, data):
        return str(data.get("identificacao"))

    def extract_common_fields(self, data):
        nome_completo = data.get("nome_registro")
        if nome_social := data.get("nome_social"):
            nome_completo = nome_social
        primeiro_nome, *_, ultimo_nome = nome_completo.split()
        return dict(
            username=data.get("identificacao"),
            email=data.get("email"),
            first_name=primeiro_nome,
            last_name=ultimo_nome,
        )


provider_classes = [SuapOAuth2Provider]
